Uniform
=======

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. autoclass:: moderngl.Uniform

Methods
-------

.. automethod:: Uniform.read() -> bytes
.. automethod:: Uniform.write(data)

Attributes
----------

.. autoattribute:: Uniform.location
.. autoattribute:: Uniform.dimension
.. autoattribute:: Uniform.array_length
.. autoattribute:: Uniform.name
.. autoattribute:: Uniform.value

.. toctree::
    :maxdepth: 2
